import { ILogger } from 'ts-smart-logger';
import { Store } from 'redux';
import { AnyT } from '../definitions.interface';
import { ISettingsEntity } from '../settings';
import { IChannel, IChannelClient } from './channel.interface';
import { PayloadWrapper } from './protocol';
import { IStoreEntity } from '../definition';
export declare abstract class BaseChannel<TConfig = AnyT, TMessage = unknown> implements IChannel<TConfig, TMessage> {
    protected static readonly logger: ILogger;
    protected readonly settings: ISettingsEntity;
    protected readonly appStore: Store<IStoreEntity>;
    private readonly clients;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {TConfig} config
     */
    abstract connect(ip: string, config?: TConfig): void;
    /**
     * @stable [04.11.2020]
     * @param ip
     */
    disconnect(ip: any): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    onConnect(ip: string, client: IChannelClient): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    onDisconnect(ip: string, client: IChannelClient): void;
    /**
     * @stable [25.05.2018]
     * @param {string} ip
     * @param {string} messageName
     * @param {AnyT} payload
     */
    onMessage(ip: string, messageName?: string, payload?: AnyT): void;
    /**
     * @stable [04.11.2020]
     * @param ip
     * @param $event
     * @param args
     */
    emitEvent(ip: string, $event: string, ...args: TMessage[]): void;
    /**
     * @stable [12.12.2018]
     * @param {string} ip
     * @param {TMessage} args
     */
    emitChannelEvent(ip: string, ...args: TMessage[]): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {PayloadWrapper} requestPayload
     */
    emitRequestPayload(ip: string, requestPayload: PayloadWrapper): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    protected registerClient(ip: string, client: IChannelClient): void;
    /**
     * @stable [11.12.2018]
     * @param {string} ip
     */
    protected unregisterClient(ip: string): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    protected registerChannelEvent(ip: string, client: IChannelClient): void;
    /**
     * @stable [21.05.2018]
     * @returns {string}
     */
    protected get eventToListen(): string;
    /**
     * @stable [21.05.2018]
     * @returns {string}
     */
    protected get eventToEmit(): string;
    /**
     * @stable [21.05.2018]
     * @param {string} message
     * @returns {AnyT}
     */
    private toMessage;
}
